@@ -35,8 +35,7 @@
 #'     class 'ichimoku'. It can be invoked by calling plot(x) on an object 'x'
 #'     of class 'ichimoku'.
 #'
-#' @section Further Details:
-#'     Please refer to the reference vignette by running:
+#'     For further details please refer to the reference vignette by calling:
 #'     \code{vignette("reference", package = "ichimoku")}
 #'
 #' @examples
@@ -85,7 +84,7 @@ plot.ichimoku <- function(x,
 #' @export
 NULL
 
-#' autoplot.ichimoku
+#' Plot Ichimoku Objects with ggplot2
 #'
 #' Plot Ichimoku Kinko Hyo cloud charts from ichimoku objects.
 #'
@@ -99,10 +98,6 @@ NULL
 #'     for class 'ichimoku'. It can be invoked by calling autoplot(x) on an
 #'     object 'x' of class 'ichimoku'.
 #'
-#' @section Further Details:
-#'     Please refer to the reference vignette by running:
-#'     \code{vignette("reference", package = "ichimoku")}
-#'
 #' @rdname autoplot.ichimoku
 #' @method autoplot ichimoku
 #' @keywords internal
@@ -118,18 +113,19 @@ autoplot.ichimoku <- function(object,
 
   theme <- match.arg(theme)
   pal <- ichimoku_themes[[theme]]
+  showstrat <- hasStrat(object) && isTRUE(strat)
   if (missing(ticker)) ticker <- attr(object, "ticker")
   if (missing(subtitle)) {
-    subtitle <- if (hasStrat(object) && isTRUE(strat)) paste0("Strategy: ", attr(object, "strat")["Strategy", ][[1L]])
+    subtitle <- if (showstrat) paste0("Strategy: ", attr(object, "strat")["Strategy", ][[1L]])
   }
 
   if (!missing(window)) object <- object[window]
-  data <- xts_df(object)
+  data <- as.data.frame.ichimoku(object)
   data$idx <- attr(data, "row.names")
   data$cd <- as.character(.subset2(data, "cd"))
 
   layers <- list(
-    if (hasStrat(object) && isTRUE(strat)) {
+    if (showstrat) {
       geom_rect(aes(xmin = .data$posn * (.data$idx - 0.5), xmax = .data$posn * (.data$idx + 0.5),
                     ymin = -Inf, ymax = Inf), fill = pal[1L], alpha = 0.2, na.rm = TRUE)
     },
@@ -160,7 +156,7 @@ autoplot.ichimoku <- function(object,
 
 }
 
-#' extraplot
+#' Plot Ichimoku Objects with ggplot2 and gtable
 #'
 #' Plot Ichimoku Kinko Hyo cloud charts from ichimoku objects with a sub-plot for
 #'     oscillators or a custom specified variable.
@@ -177,10 +173,6 @@ autoplot.ichimoku <- function(object,
 #'     of a stochastic oscillator. The oscillator look-back parameters are based
 #'     on the fast and medium cloud periods of the ichimoku object.
 #'
-#' @section Further Details:
-#'     Please refer to the reference vignette by running:
-#'     \code{vignette("reference", package = "ichimoku")}
-#'
 #' @keywords internal
 #' @export
 #'
@@ -200,43 +192,42 @@ extraplot <- function(object,
   aplot <- autoplot.ichimoku(object = object, window = window, ticker = ticker,
                              subtitle = subtitle, theme = theme, strat = strat)
 
-  if (type == "none") {
+  type == "none" && {
     warning("Required argument 'type' not specified or set to 'none'", call. = FALSE)
     return(print(aplot))
   }
   if (type == "bar" || type == "line") {
-    if(missing(custom)) {
+    missing(custom) && {
       warning("For type = 'bar' or 'line': required argument 'custom' not specified", call. = FALSE)
       return(print(aplot))
     }
     cnames <- dimnames(object)[[2L]]
     sel <- grep(custom, cnames, ignore.case = TRUE, perl = TRUE)[1L]
-    if (is.na(sel)) {
+    is.na(sel) && {
       warning("Specified value '", custom, "' for 'custom' does not match any columns", call. = FALSE)
       return(print(aplot))
     }
 
   } else if (type == "r") {
     p2 <- attr(object, "periods")[2L]
-    object$rtype_osc <- 100 - 100 / (1 + meanOver((object[, "cd"] == 1) * (object[, "close"] - object[, "open"]), p2) / meanOver((object[, "cd"] == -1) * (object[, "open"] - object[, "close"]), p2))
+    object$osc_typ_slw <- 100 - 100 / (1 + meanOver((object[, "cd"] == 1) * (object[, "close"] - object[, "open"]), p2) / meanOver((object[, "cd"] == -1) * (object[, "open"] - object[, "close"]), p2))
 
   } else {
     periods <- attr(object, "periods")
     p1 <- periods[1L]
     p2 <- periods[2L]
-    object$stype_fast <- 100 * (object[, "close"] - minOver(object[, "low"], p1)) / (maxOver(object[, "high"], p1) - minOver(object[, "low"], p1))
-    object$stype_slow <- 100 * (object[, "close"] - minOver(object[, "low"], p2)) / (maxOver(object[, "high"], p2) - minOver(object[, "low"], p2))
+    object$osc_typ_fst <- 100 * (object[, "close"] - minOver(object[, "low"], p1)) / (maxOver(object[, "high"], p1) - minOver(object[, "low"], p1))
+    object$osc_typ_slw <- 100 * (object[, "close"] - minOver(object[, "low"], p2)) / (maxOver(object[, "high"], p2) - minOver(object[, "low"], p2))
   }
 
   if (!missing(window)) object <- object[window]
-  data <- xts_df(object)
+  data <- as.data.frame.ichimoku(object)
   data$idx <- attr(data, "row.names")
 
   if (type == "r" || type == "s") {
     layers <- list(
-      if (type == "r") geom_line(aes(y = .data$rtype_osc), color = pal[5L], na.rm = TRUE),
-      if (type == "s") geom_line(aes(y = .data$stype_fast), color = pal[4L], na.rm = TRUE),
-      if (type == "s") geom_line(aes(y = .data$stype_slow), color = pal[5L], na.rm = TRUE),
+      geom_line(aes(y = .data$osc_typ_slw), color = pal[5L], alpha = 0.8, na.rm = TRUE),
+      if (type == "s") geom_line(aes(y = .data$osc_typ_fst), color = pal[4L], alpha = 0.7, na.rm = TRUE),
       scale_x_continuous(breaks = breaks_ichimoku(data = data, object = object), labels = NULL),
       scale_y_continuous(breaks = c(0, 25, 50, 75, 100), limits = c(0, 100), expand = c(0,0)),
       labs(x = NULL, y = switch(type, r = "R-type", s = "S-type")),
@@ -252,11 +243,11 @@ extraplot <- function(object,
 
     layers <- list(
       if (type == "line") {
-        geom_line(aes(y = .data[[cols]]), color = pal[7L], na.rm = TRUE)
+        geom_line(aes(y = .data[[cols]]), color = pal[7L], alpha = 0.8, na.rm = TRUE)
       } else {
         geom_rect(aes(xmin = .data$idx - 0.4, xmax = .data$idx + 0.4, ymin = 0,
                       ymax = .data[[cols]], color = .data$cd, fill = .data$cd),
-                  size = 0.3, na.rm = TRUE)
+                  size = 0.3, alpha = 0.8, na.rm = TRUE)
       },
       scale_x_continuous(breaks = breaks_ichimoku(data = data, object = object), labels = NULL),
       scale_y_continuous(),
