@@ -2,8 +2,8 @@ test_that("archive functions ok", {
   skip_if_not_installed("openssl")
   object <- ichimoku(sample_ohlc_data)
   file <- tempfile()
-  archive(object = object, file = file)
-  restored <- archive(file = file)
+  expect_message(archive(object = object, file = file), "Archive written")
+  expect_message(restored <- archive(file = file), "Archive read")
   unlink(file)
   expect_identical(restored, object)
   expect_error(archive(object, object, object), "3 arguments passed")
@@ -17,11 +17,11 @@ test_that("archive functions ok", {
   file <- tempfile()
   x_archive_sha256 <- NA
   save(object, x_archive_sha256, file = file)
-  expect_message(archive(file), "unverified")
+  expect_message(restored <- archive(file), "unverified")
   unlink(file)
   x_archive_sha256 <- "010101010101"
   file <- tempfile()
   save(object, x_archive_sha256, file = file)
-  expect_warning(archive(file), "does not match the original")
+  expect_warning(restored <- archive(file), "does not match the original")
   unlink(file)
 })
